<?php
include "../../conn/conn.php";

// 获取药品ID
$medication_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($medication_id <= 0) {
    echo "<script>alert('无效的药品ID'); window.location.href='list.php';</script>";
    exit;
}

// 查询药品信息
$sql = "SELECT * FROM medications WHERE id = $medication_id";
$result = mysqli_query($connID, $sql);

if (mysqli_num_rows($result) == 0) {
    echo "<script>alert('药品不存在'); window.location.href='list.php';</script>";
    exit;
}

$medication = mysqli_fetch_assoc($result);

// 获取药品使用统计信息
$stats_sql = "SELECT 
    COUNT(DISTINCT mr.id) as total_prescriptions,
    COUNT(DISTINCT mr.patient_id) as total_patients,
    COUNT(CASE WHEN DATE(mr.created_at) = CURDATE() THEN 1 END) as today_prescriptions,
    COUNT(CASE WHEN mr.created_at >= DATE_SUB(NOW(), INTERVAL 30 DAY) THEN 1 END) as month_prescriptions
    FROM medical_records mr 
    WHERE mr.prescription LIKE '%{$medication['name']}%'";

$stats_result = mysqli_query($connID, $stats_sql);
$stats = mysqli_fetch_assoc($stats_result);

// 获取最近的处方记录
$recent_prescriptions_sql = "SELECT mr.*, p.name as patient_name, p.phone as patient_phone, d.name as doctor_name
                             FROM medical_records mr
                             JOIN patients p ON mr.patient_id = p.id
                             JOIN doctors d ON mr.doctor_id = d.id
                             WHERE mr.prescription LIKE '%{$medication['name']}%'
                             ORDER BY mr.created_at DESC
                             LIMIT 5";

$recent_prescriptions_result = mysqli_query($connID, $recent_prescriptions_sql);
?>

<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>药品详情 - <?php echo htmlspecialchars($medication['name']); ?> - 电子病历系统</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap" rel="stylesheet">
    <link href="../../css/material.css" rel="stylesheet">
    <style>
        .medication-header {
            background: linear-gradient(135deg, #26a69a 0%, #00796b 100%);
            color: white;
            padding: 2rem;
            border-radius: 12px;
            margin-bottom: 2rem;
            position: relative;
            overflow: hidden;
        }
        .medication-header::before {
            content: '';
            position: absolute;
            top: 0;
            right: 0;
            width: 200px;
            height: 200px;
            background: rgba(255, 255, 255, 0.1);
            border-radius: 50%;
            transform: translate(50%, -50%);
        }
        .medication-avatar {
            width: 80px;
            height: 80px;
            background: rgba(255, 255, 255, 0.2);
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 2rem;
            margin-bottom: 1rem;
            border: 3px solid rgba(255, 255, 255, 0.3);
        }
        .medication-name {
            font-size: 2rem;
            font-weight: 500;
            margin-bottom: 0.5rem;
        }
        .medication-spec {
            font-size: 1.2rem;
            opacity: 0.9;
            margin-bottom: 0.5rem;
        }
        .medication-id {
            background: rgba(255, 255, 255, 0.2);
            display: inline-block;
            padding: 0.3rem 0.8rem;
            border-radius: 20px;
            font-size: 0.9rem;
        }
        .price-badge {
            background: linear-gradient(45deg, #ffa726, #ff9800);
            color: white;
            padding: 0.5rem 1rem;
            border-radius: 25px;
            font-size: 1.2rem;
            font-weight: 600;
            display: inline-block;
            margin-left: 1rem;
        }
        .stats-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 1rem;
            margin-bottom: 2rem;
        }
        .stat-card {
            background: white;
            padding: 1.5rem;
            border-radius: 12px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            text-align: center;
            transition: transform 0.3s ease;
        }
        .stat-card:hover {
            transform: translateY(-5px);
        }
        .stat-number {
            font-size: 2.5rem;
            font-weight: 700;
            margin-bottom: 0.5rem;
        }
        .stat-label {
            color: #666;
            font-size: 0.9rem;
        }
        .info-grid {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 2rem;
        }
        .info-item {
            padding: 1rem 0;
            border-bottom: 1px solid #eee;
        }
        .info-item:last-child {
            border-bottom: none;
        }
        .info-label {
            font-weight: 500;
            color: #666;
            margin-bottom: 0.3rem;
        }
        .info-value {
            font-size: 1.1rem;
            color: #333;
        }
        .recent-prescriptions {
            margin-top: 2rem;
        }
        .prescription-item {
            padding: 1rem;
            border: 1px solid #eee;
            border-radius: 8px;
            margin-bottom: 1rem;
            transition: box-shadow 0.3s ease;
        }
        .prescription-item:hover {
            box-shadow: 0 2px 8px rgba(0,0,0,0.1);
        }
        .prescription-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 0.5rem;
        }
        .patient-name {
            font-weight: 500;
            color: #1976d2;
        }
        .prescription-date {
            color: #666;
            font-size: 0.9rem;
        }
        .doctor-info {
            color: #26a69a;
            font-weight: 500;
        }
        .safety-info {
            background: #fff3e0;
            border-left: 4px solid #ff9800;
            padding: 1rem;
            border-radius: 8px;
            margin-top: 1rem;
        }
        .safety-title {
            font-weight: 600;
            color: #ef6c00;
            margin-bottom: 0.5rem;
        }
        @media (max-width: 768px) {
            .info-grid {
                grid-template-columns: 1fr;
                gap: 1rem;
            }
            .medication-header {
                padding: 1.5rem;
            }
            .medication-name {
                font-size: 1.5rem;
            }
            .price-badge {
                margin-left: 0;
                margin-top: 0.5rem;
            }
        }
    </style>
</head>
<body>
    <header class="header">
        <h1>
            <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                <path d="M17,3C18.1,3 19,3.9 19,5V8H21V10H19V19C19,20.1 18.1,21 17,21H7C5.9,21 5,20.1 5,19V10H3V8H5V5C5,3.9 5.9,3 7,3H17M7,5V8H17V5H7M7,10V19H17V10H7M9,12H15V14H9V12M9,15H13V17H9V15Z"/>
            </svg>
            药品详情
        </h1>
    </header>

    <nav class="nav-menu">
        <ul>
            <li><a href="../../index.php">
                <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                    <path d="M10,20V14H14V20H19V12H22L12,3L2,12H5V20H10Z"/>
                </svg>
                仪表板
            </a></li>
            <li><a href="../patients/list.php">
                <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                    <path d="M12,4A4,4 0 0,1 16,8A4,4 0 0,1 12,12A4,4 0 0,1 8,8A4,4 0 0,1 12,4M12,14C16.42,14 20,15.79 20,18V20H4V18C4,15.79 7.58,14 12,14Z"/>
                </svg>
                患者管理
            </a></li>
            <li><a href="../doctors/list.php">
                <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                    <path d="M14.84,2.5C16.2,2.5 17.5,3.2 18.28,4.38L18.5,4.75L19.25,4.38C19.92,4 20.75,4.2 21.13,4.87C21.5,5.54 21.33,6.42 20.66,6.79L20.04,7.12C20.04,7.12 20.04,7.12 20.04,7.12C20.47,7.88 20.47,8.78 20.04,9.54L20.5,9.78C21.17,10.15 21.33,11.04 20.97,11.71C20.6,12.38 19.72,12.54 19.05,12.17L18.5,11.88C17.71,13.07 16.39,13.77 15.04,13.77C13.68,13.77 12.36,13.07 11.57,11.88L11,12.17C10.33,12.54 9.45,12.38 9.08,11.71C8.71,11.04 8.88,10.15 9.55,9.78L10,9.54C9.58,8.78 9.58,7.88 10,7.12L9.38,6.79C8.71,6.42 8.55,5.54 8.92,4.87C9.29,4.2 10.17,4 10.84,4.38L11.57,4.75C12.35,3.56 13.67,2.86 15.04,2.86M15.04,4.64C14.18,4.64 13.4,5.09 12.96,5.78L12.5,6.5L11.78,6.06C11.58,5.94 11.32,6 11.19,6.21C11.07,6.42 11.13,6.68 11.34,6.81L12.06,7.25L11.78,7.94C11.58,8.38 11.58,8.87 11.78,9.31L12.06,10L11.34,10.44C11.13,10.57 11.07,10.83 11.19,11.04C11.32,11.25 11.58,11.31 11.78,11.19L12.5,10.75L12.96,11.47C13.4,12.16 14.18,12.61 15.04,12.61C15.9,12.61 16.68,12.16 17.12,11.47L17.58,10.75L18.3,11.19C18.5,11.31 18.76,11.25 18.89,11.04C19.01,10.83 18.95,10.57 18.74,10.44L18.02,10L18.3,9.31C18.5,8.87 18.5,8.38 18.3,7.94L18.02,7.25L18.74,6.81C18.95,6.68 19.01,6.42 18.89,6.21C18.76,6 18.5,5.94 18.3,6.06L17.58,6.5L17.12,5.78C16.68,5.09 15.9,4.64 15.04,4.64M11,15.5V17.5H3V15.5C3,14.39 6.69,13.5 9.5,13.5C10.4,13.5 11.5,13.65 12.5,13.91C11.84,14.8 11.5,15.88 11.5,17C11.34,16.83 11.17,16.66 11,15.5M9.5,12A2.5,2.5 0 0,1 7,9.5A2.5,2.5 0 0,1 9.5,7A2.5,2.5 0 0,1 12,9.5A2.5,2.5 0 0,1 9.5,12Z"/>
                </svg>
                医生管理
            </a></li>
            <li><a href="../medical_records/list.php">
                <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                    <path d="M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M18,20H6V4H13V9H18V20Z"/>
                </svg>
                病历管理
            </a></li>
            <li><a href="../departments/list.php">
                <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                    <path d="M12,11.5A2.5,2.5 0 0,1 9.5,9A2.5,2.5 0 0,1 12,6.5A2.5,2.5 0 0,1 14.5,9A2.5,2.5 0 0,1 12,11.5M12,2A7,7 0 0,0 5,9C5,14.25 12,22 12,22C12,22 19,14.25 19,9A7,7 0 0,0 12,2Z"/>
                </svg>
                科室管理
            </a></li>
            <li><a href="list.php" class="active">
                <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                    <path d="M17,3C18.1,3 19,3.9 19,5V8H21V10H19V19C19,20.1 18.1,21 17,21H7C5.9,21 5,20.1 5,19V10H3V8H5V5C5,3.9 5.9,3 7,3H17M7,5V8H17V5H7M7,10V19H17V10H7M9,12H15V14H9V12M9,15H13V17H9V15Z"/>
                </svg>
                药品管理
            </a></li>
        </ul>
    </nav>

    <div class="container">
        <!-- 药品头部信息 -->
        <div class="medication-header">
            <div class="medication-avatar">
                💊
            </div>
            <div class="medication-name">
                <?php echo htmlspecialchars($medication['name']); ?>
                <?php if ($medication['price'] > 0): ?>
                    <span class="price-badge">¥<?php echo number_format($medication['price'], 2); ?></span>
                <?php endif; ?>
            </div>
            <div class="medication-spec"><?php echo htmlspecialchars($medication['specification']); ?> • <?php echo htmlspecialchars($medication['unit']); ?></div>
            <div class="medication-id">药品编号: <?php echo $medication['id']; ?></div>
        </div>

        <!-- 统计卡片 -->
        <div class="stats-grid">
            <div class="stat-card">
                <div class="stat-number" style="color: #1976d2;"><?php echo $stats['total_prescriptions']; ?></div>
                <div class="stat-label">总处方次数</div>
            </div>
            <div class="stat-card">
                <div class="stat-number" style="color: #388e3c;"><?php echo $stats['total_patients']; ?></div>
                <div class="stat-label">使用患者数</div>
            </div>
            <div class="stat-card">
                <div class="stat-number" style="color: #f57c00;"><?php echo $stats['today_prescriptions']; ?></div>
                <div class="stat-label">今日处方</div>
            </div>
            <div class="stat-card">
                <div class="stat-number" style="color: #7b1fa2;"><?php echo $stats['month_prescriptions']; ?></div>
                <div class="stat-label">本月处方</div>
            </div>
        </div>

        <div class="info-grid">
            <!-- 基本信息 -->
            <div class="card">
                <div class="card-header">
                    <h3 class="card-title">
                        <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                            <path d="M17,3C18.1,3 19,3.9 19,5V8H21V10H19V19C19,20.1 18.1,21 17,21H7C5.9,21 5,20.1 5,19V10H3V8H5V5C5,3.9 5.9,3 7,3H17M7,5V8H17V5H7M7,10V19H17V10H7M9,12H15V14H9V12M9,15H13V17H9V15Z"/>
                        </svg>
                        基本信息
                    </h3>
                </div>
                <div class="card-content">
                    <div class="info-item">
                        <div class="info-label">药品名称</div>
                        <div class="info-value"><?php echo htmlspecialchars($medication['name']); ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">药品规格</div>
                        <div class="info-value"><?php echo htmlspecialchars($medication['specification']); ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">计量单位</div>
                        <div class="info-value"><?php echo htmlspecialchars($medication['unit']); ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">单价</div>
                        <div class="info-value">
                            <?php if ($medication['price'] > 0): ?>
                                <strong style="color: #1976d2;">¥<?php echo number_format($medication['price'], 2); ?></strong>
                            <?php else: ?>
                                <span style="color: #999;">未设置</span>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">入库时间</div>
                        <div class="info-value"><?php echo date('Y年m月d日', strtotime($medication['created_at'])); ?></div>
                    </div>
                </div>
            </div>

            <!-- 生产信息 -->
            <div class="card">
                <div class="card-header">
                    <h3 class="card-title">
                        <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                            <path d="M12,15.5A3.5,3.5 0 0,1 8.5,12A3.5,3.5 0 0,1 12,8.5A3.5,3.5 0 0,1 15.5,12A3.5,3.5 0 0,1 12,15.5M19.43,12.97C19.47,12.65 19.5,12.33 19.5,12C19.5,11.67 19.47,11.34 19.43,11L21.54,9.37C21.73,9.22 21.78,8.95 21.66,8.73L19.66,5.27C19.54,5.05 19.27,4.96 19.05,5.05L16.56,6.05C16.04,5.66 15.5,5.32 14.87,5.07L14.5,2.42C14.46,2.18 14.25,2 14,2H10C9.75,2 9.54,2.18 9.5,2.42L9.13,5.07C8.5,5.32 7.96,5.66 7.44,6.05L4.95,5.05C4.73,4.96 4.46,5.05 4.34,5.27L2.34,8.73C2.22,8.95 2.27,9.22 2.46,9.37L4.57,11C4.53,11.34 4.5,11.67 4.5,12C4.5,12.33 4.53,12.65 4.57,12.97L2.46,14.63C2.27,14.78 2.22,15.05 2.34,15.27L4.34,18.73C4.46,18.95 4.73,19.03 4.95,18.95L7.44,17.94C7.96,18.34 8.5,18.68 9.13,18.93L9.5,21.58C9.54,21.82 9.75,22 10,22H14C14.25,22 14.46,21.82 14.5,21.58L14.87,18.93C15.5,18.68 16.04,18.34 16.56,17.94L19.05,18.95C19.27,19.03 19.54,18.95 19.66,18.73L21.66,15.27C21.78,15.05 21.73,14.78 21.54,14.63L19.43,12.97Z"/>
                        </svg>
                        生产信息
                    </h3>
                </div>
                <div class="card-content">
                    <div class="info-item">
                        <div class="info-label">生产厂家</div>
                        <div class="info-value"><?php echo htmlspecialchars($medication['manufacturer']); ?></div>
                    </div>
                </div>
            </div>
        </div>

        <!-- 最近处方记录 -->
        <div class="recent-prescriptions">
            <div class="card">
                <div class="card-header">
                    <h3 class="card-title">
                        <svg class="icon" viewBox="0 0 24 24" fill="currentColor">
                            <path d="M9,10H7V12H9V10M13,10H11V12H13V10M17,10H15V12H17V10M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5A2,2 0 0,1 5,3H6V1H8V3H16V1H18V3H19M19,19V8H5V19H19M9,14H7V16H9V14M13,14H11V16H13V14M17,14H15V16H17V14Z"/>
                        </svg>
                        最近处方记录
                    </h3>
                </div>
                <div class="card-content">
                    <?php if (mysqli_num_rows($recent_prescriptions_result) > 0): ?>
                        <?php while($prescription = mysqli_fetch_assoc($recent_prescriptions_result)): ?>
                        <div class="prescription-item">
                            <div class="prescription-header">
                                <span class="patient-name"><?php echo htmlspecialchars($prescription['patient_name']); ?></span>
                                <span class="prescription-date"><?php echo date('Y-m-d H:i', strtotime($prescription['created_at'])); ?></span>
                            </div>
                            <div style="margin-bottom: 0.5rem;">
                                主治医生: <span class="doctor-info"><?php echo htmlspecialchars($prescription['doctor_name']); ?></span>
                            </div>
                            <div style="color: #666; margin-bottom: 0.5rem;">
                                联系电话: <?php echo htmlspecialchars($prescription['patient_phone']); ?>
                            </div>
                            <div style="color: #333;">
                                处方详情: <?php echo htmlspecialchars(mb_substr($prescription['prescription'], 0, 100, 'UTF-8')); ?>
                                <?php if (mb_strlen($prescription['prescription'], 'UTF-8') > 100): ?>...<?php endif; ?>
                            </div>
                            <div style="margin-top: 0.5rem;">
                                <a href="../medical_records/view.php?id=<?php echo $prescription['id']; ?>" class="btn btn-small btn-primary">查看详情</a>
                            </div>
                        </div>
                        <?php endwhile; ?>
                        <div style="text-align: center; margin-top: 1rem;">
                            <a href="../medical_records/list.php?medication=<?php echo urlencode($medication['name']); ?>" class="btn btn-primary">查看全部处方</a>
                        </div>
                    <?php else: ?>
                        <div style="text-align: center; color: #999; padding: 2rem;">
                            暂无处方记录
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- 操作按钮 -->
        <div style="margin-top: 2rem; text-align: center;">
            <a href="list.php" class="btn btn-primary">返回药品列表</a>
            <a href="edit.php?id=<?php echo $medication_id; ?>" class="btn btn-warning">编辑信息</a>
            <a href="../medical_records/add.php?medication_id=<?php echo $medication_id; ?>" class="btn btn-success">开具处方</a>
        </div>
    </div>
</body>
</html> 